package main

import (
	"context"
	"fmt"
	"io"
	"net/url"
	"os"

	"gitea.stevedudenhoeffer.com/steve/go-extractor/cmd/browser/pkg/browser"

	"github.com/urfave/cli/v3"

	"gitea.stevedudenhoeffer.com/steve/go-extractor/sites/wegmans"
)

func deferClose(cl io.Closer) {
	if cl != nil {
		_ = cl.Close()
	}
}

type WegmansFlags []cli.Flag

var Flags = WegmansFlags{}

func (f WegmansFlags) ToConfig(_ *cli.Command) wegmans.Config {
	var res = wegmans.DefaultConfig

	return res
}

func main() {
	var flags []cli.Flag

	flags = append(flags, browser.Flags...)
	flags = append(flags, Flags...)

	app := &cli.Command{
		Name:  "wegmans",
		Usage: "Search Wegmans",
		Flags: flags,
		Action: func(ctx context.Context, cmd *cli.Command) error {
			cfg := Flags.ToConfig(cmd)

			b, err := browser.FromCommand(ctx, cmd)
			defer deferClose(b)

			if err != nil {
				return fmt.Errorf("error creating browser: %w", err)
			}
			arg := cmd.Args().First()

			if arg == "" {
				return fmt.Errorf("url is required")
			}

			u, err := url.Parse(arg)

			if err != nil {
				return fmt.Errorf("failed to parse url: %w", err)
			}

			item, err := cfg.GetItemPrice(ctx, b, u)

			if err != nil {
				return fmt.Errorf("failed to get item price: %w", err)
			}

			fmt.Println(item)

			return nil
		},
	}

	err := app.Run(context.Background(), os.Args)

	if err != nil {
		panic(err)
	}
}
